==> apache-any23-2.2-src.zip: apache-any23-2.2-src/core/src/main/java/org/apache/any23/extractor/yaml/YAMLProcessorException.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.any23.extractor.yaml;

import javax.annotation.Nullable;

/**
 *
 * @author Jacek Grzebyta (grzebyta.dev [at] gmail.com)
 */
public class YAMLProcessorException extends RuntimeException {
    
    @Nullable
    private Object reason;

    public Object getReason() {
        return reason;
    }

    public YAMLProcessorException() {
        super();
    }

    public YAMLProcessorException(Object reason) {
        this.reason = reason;
    }

    public YAMLProcessorException(Object reason, String message) {
        super(message);
        this.reason = reason;
    }

    public YAMLProcessorException(Object reason, String message, Throwable cause) {
        super(message, cause);
        this.reason = reason;
    }

    public YAMLProcessorException(Object reason, Throwable cause) {
        super(cause);
        this.reason = reason;
    }

    public YAMLProcessorException(Object reason, String message, Throwable cause, boolean enableSuppression, boolean writableStackTrace) {
        super(message, cause, enableSuppression, writableStackTrace);
        this.reason = reason;
    }
    
    
    
    
}

==> apache-any23-2.7-src.zip: apache-any23-2.7-src/core/src/main/java/org/apache/any23/extractor/yaml/YAMLProcessorException.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.any23.extractor.yaml;

import javax.annotation.Nullable;

/**
 *
 * @author Jacek Grzebyta (grzebyta.dev [at] gmail.com)
 */
public class YAMLProcessorException extends RuntimeException {

    @Nullable
    private Object reason;

    public Object getReason() {
        return reason;
    }

    public YAMLProcessorException() {
        super();
    }

    public YAMLProcessorException(Object reason) {
        this.reason = reason;
    }

    public YAMLProcessorException(Object reason, String message) {
        super(message);
        this.reason = reason;
    }

    public YAMLProcessorException(Object reason, String message, Throwable cause) {
        super(message, cause);
        this.reason = reason;
    }

    public YAMLProcessorException(Object reason, Throwable cause) {
        super(cause);
        this.reason = reason;
    }

    public YAMLProcessorException(Object reason, String message, Throwable cause, boolean enableSuppression,
            boolean writableStackTrace) {
        super(message, cause, enableSuppression, writableStackTrace);
        this.reason = reason;
    }

}
